@@ -556,9 +556,6 @@ class DataFrame:
                 self.set_dataframe(self.__dataframe[self.__dataframe[drop_row_if_nan_in_column].notna()])
                 #self.__dataframe = self.__dataframe[~(np.isnan(self.__dataframe).any(axis=1))] # removes rows containing at least one nan
           
-       
-            
-        
     def get_row(self, row_index):
         if isinstance(row_index, int):
             return self.get_dataframe().iloc[row_index]
@@ -780,7 +777,7 @@ class DataFrame:
     def count_occurence_of_row_as_count_column(self, column):
         column_name = 'count'
         self.set_column(column_name, self.get_column(column).value_counts())
-        self.trasform_column(column_name, column, lambda x:self.get_column(column).value_counts().get(x))
+        self.transform_column(column_name, column, lambda x:self.get_column(column).value_counts().get(x))
     
     def get_count_number_of_all_words(self, column):
         self.apply_fun_to_column(column, lambda x: len(x.split(' ')))
@@ -1100,6 +1097,7 @@ class DataFrame:
                 self.transform_column(name, name, log_function, min_column)
         self.convert_dataframe_type()
         return self.get_dataframe()
+    
     def load_dataset(self, dataset='iris'):
         """
         boston: Load and return the boston house-prices dataset (regression)
@@ -1125,11 +1123,8 @@ class DataFrame:
         if similarity_method == 'cosine':
             corpus = self.get_column_as_list(column_name1) + self.get_column_as_list(column_name2)
             vectorizer = Vectorizer(corpus, weighting_method)
-            print(len(self.get_column_as_list(column_name1)))
-            print(len(self.get_column_as_list(column_name2)))
             new_column = []
             for p in zip(self.get_column_as_list(column_name1), self.get_column_as_list(column_name2)):
-                print(p)
                 new_column.append(vectorizer.cosine_similarity(p[0], p[1])) 
             
             self.add_column(new_column, 'Similarity score')
